@@ -7,7 +7,7 @@ use warnings;
 
 use 5.008;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 __PACKAGE__
 
@@ -19,10 +19,6 @@ __END__
 
 Task::KiokuDB - Install L<KiokuDB> and related modules.
 
-=head1 SYNOPSIS
-
-	cpan> install Task::KiokuDB
-
 =head1 DESCRIPTION
 
 This bundle installs L<KiokuDB> and depending on the environment several
@@ -38,10 +34,6 @@ All of these are considered optional.
 
 Commands for the C<kioku> command line program.
 
-=item L<KiokuDB::Backend::Files>
-
-The file backend. Defaults to true.
-
 =item L<KiokuDB::Backend::BDB>
 
 L<BerkeleyDB> backend. Requires an installed BerkeleyDB, preferably linked
